\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{kussthesis}[2024/03/29]
\makeatletter
\RequirePackage{ifptex}
\RequirePackage{ifuptex}
\RequirePackage{ifluatex}
\ifpTeX
	\RequirePackage{plautopatch}
	\LoadClass[uplatex,dvipdfmx,10pt,book,twoside,
	line_length=40zw,number_of_lines=40,gutter=10zw]{jlreq}
	\RequirePackage{jlreq-deluxe}
\fi
\ifLuaTeX
	\LoadClass[10pt,book,twoside,
	line_length=40zw,number_of_lines=40,gutter=10zw]{jlreq}
\fi
\RequirePackage[l2tabu, orthodox]{nag}
\RequirePackage{xparse}
\RequirePackage[bookmarks=true,setpagesize=false,bookmarksnumbered=true,colorlinks=false,pdfusetitle]{hyperref}
\ifpTeX
	\RequirePackage{amsmath}
	\RequirePackage{tgtermes}
	\RequirePackage{tgheros}
	\RequirePackage{inconsolata}
	\RequirePackage[notext]{stix}
	\RequirePackage{otf}
	\RequirePackage[haranoaji]{pxchfon}
	\setlightminchofont{HaranoAjiMincho-Light.otf}
	\setmediumminchofont{HaranoAjiMincho-Medium.otf}
	\setboldminchofont{HaranoAjiMincho-Bold.otf}
	\setmediumgothicfont{HaranoAjiGothic-Medium.otf}
	\setboldgothicfont{HaranoAjiGothic-Bold.otf}
	\setxboldgothicfont{HaranoAjiGothic-Heavy.otf}
\fi
\ifLuaTeX
	\RequirePackage{fontspec}
	\RequirePackage{stix}
	\RequirePackage{amsmath}
	\setmainfont{TeX Gyre Termes}
	\setsansfont{TeX Gyre Heros}
	\setmonofont[BoldFont=Inconsolatazi4-Bold]{Inconsolata}
	\RequirePackage[haranoaji,deluxe,expert]{luatexja-preset}
	\setmainjfont[
		FontFace = {el}{\shapedefault}{ *-ExtraLight },
		FontFace = {l}{\shapedefault}{ *-Light },
		FontFace = {m}{\shapedefault}{ *-Regular },
		FontFace = {sb}{\shapedefault}{ *-Medium },
		FontFace = {b}{\shapedefault}{ *-Bold },
		FontFace = {eb}{\shapedefault}{ *-Heavy }% eb の Bold を Heavy で上書き
	  ]{HaranoAjiMincho}
	  \setsansjfont[
		FontFace = {el}{\shapedefault}{ *-ExtraLight },
		FontFace = {l}{\shapedefault}{ *-Light },% l の Regular を Light で上書き
		FontFace = {sl}{\shapedefault}{ *-Regular },
		FontFace = {m}{\shapedefault}{ *-Medium },
		FontFace = {b}{\shapedefault}{ *-Bold },
		FontFace = {eb}{\shapedefault}{ *-Heavy },
	  ]{HaranoAjiGothic}
	  \def\jttdefault{\gtdefault}
\fi
%\RequirePackage[a4paper,includemp,twoside,bindingoffset=5\zw]{geometry}
\RequirePackage[hiresbb]{graphicx}
\RequirePackage[svgnames]{xcolor}
\RequirePackage{siunitx}
\RequirePackage{tabularray}
\RequirePackage{booktabs}
\RequirePackage{comment}
\UseTblrLibrary{counter,booktabs,siunitx,amsmath,varwidth}

\sisetup{
	mode=text, 
	detect-mode=true, 
	inter-unit-product = \ensuremath{{}\cdot{}}, 
	per-symbol=\ensuremath{{}/{}}
}
\jlreqsetup{
	caption_font=\sffamily\normalsize,caption_label_font=\sffamily\normalsize,
	caption_align=left
}
\NewColumnType{N}[1][]{S[mode=math]}
\ModifyPageStyle{headings}{
	nombre_font=\bfseries,
	running_head_position=top-left,
	nombre_position=top-right,
	odd_running_head=_section,
	even_running_head=_chapter
}
\pagestyle{headings}
\newcommand{\headrulewidth}{0.5pt}
\DefTblrTemplate{contfoot-text}{default}{（次ページへ続く）}
\DefTblrTemplate{conthead-text}{default}{（前ページより続く）}


%%% \chapter* に目次・ブックマーク処理
\def\@addchaptertoc#1{\jlreq@cleartooddpage\phantomsection\addcontentsline{toc}{chapter}{#1}}
\let\tableofcontents@orig=\tableofcontents
\def\chapter@wocnt@wtoc#1{\@addchaptertoc{#1}\chapter*{#1}}
\jlreqsetup{thebibliography_heading={\chapter@wocnt@wtoc{\refname}}}

\RenewDocumentCommand\tableofcontents{}{\@addchaptertoc{目次}\tableofcontents@orig}
\NewDocumentCommand\acknowledgment{}{\chapter@wocnt@wtoc{謝辞}}
\NewDocumentCommand\submityear{m}{\gdef\@submityear{#1}}
\NewDocumentCommand\thesistype{m}{\gdef\@thesistype{#1}}
\NewDocumentCommand\ethesistype{m}{\gdef\@ethesistype{#1}}
\NewDocumentCommand\subtitle{m}{\gdef\@subtitle{#1}}
\NewDocumentCommand\etitle{m}{\gdef\@etitle{#1}}
\NewDocumentCommand\esubtitle{m}{\gdef\@esubtitle{#1}}
\NewDocumentCommand\generation{m}{\gdef\@generation{#1}}
\NewDocumentCommand\grade{m}{\gdef\@grade{#1}}
\NewDocumentCommand\class{m}{\gdef\@class{#1}}
\NewDocumentCommand\studentnumber{m}{\gdef\@studentnumber{#1}}
\NewDocumentCommand\eauthor{m}{\gdef\@eauthor{#1}}
\NewDocumentCommand\supervisor{m}{\gdef\@supervisor{#1}}
\NewDocumentCommand\keywords{m}{\gdef\@keywords{#1}}
\NewDocumentCommand\ekeywords{m}{\gdef\@ekeywords{#1}}
\RenewDocumentCommand\maketitle{}{
	\hypersetup{
		pdftitle={\expandafter\@title\ifx\expandafter\@subtitle\undefined\else{：}\fi\expandafter\@subtitle},
		pdfauthor={\expandafter\@author}
	}
	\thispagestyle{empty}\centering

	
	{
		\fontsize{18pt}{24pt}\selectfont
		\expandafter\@submityear 年度\qquad\@thesistype\par
	}

	
	\vspace*{6\baselineskip}

	{
		\fontsize{36pt}{48pt}\bfseries\selectfont
		\expandafter\@title\par
	}

	\vspace*{2\baselineskip}


	{
		\fontsize{24pt}{32pt}\fontseries{sb}\selectfont
		\expandafter\@subtitle\par
	}

	\vspace*{6\baselineskip}

	{
		\fontsize{18pt}{24pt}\selectfont
		神戸大学附属中等教育学校\qquad\expandafter\@generation 回生

		\expandafter\@grade 年\expandafter\@class 組\expandafter\@studentnumber 番\par 
	}

	{
		\fontsize{24pt}{32pt}\fontseries{sb}\selectfont
		\expandafter\@author\par
	}

	\vspace*{\baselineskip}

	{
		\fontsize{18pt}{24pt}\selectfont
		（指導教員：\expandafter\@supervisor ）\par
	}

	\raggedright
	\setlength{\parindent}{1\zw}

	\clearpage

}

\NewDocumentEnvironment{jabstract}{+b}{
	\cleardoublepage\phantomsection\thispagestyle{empty}

	\addcontentsline{toc}{chapter}{和文要旨}

	\begin{center}
	\@submityear 年度\qquad \@thesistype

	{\fontsize{18pt}{27pt}\sffamily\fontseries{sb}\selectfont \@title\par}

	\vspace*{\baselineskip}

	{\fontsize{14pt}{21pt}\fontseries{sb}\selectfont \@subtitle\par}

	\vspace*{\baselineskip}

	{神戸大学附属中等教育学校\quad\@generation 回生\qquad \@grade 年\@class 組 \@studentnumber 番}

	{\fontsize{14pt}{21pt}\fontseries{sb}\selectfont \@author\par}

	{（指導教員：\@supervisor ）}
	\end{center}

	\vspace*{\baselineskip}

	\ifdefined\@keywords{\begin{center}\fontsize{12pt}{18pt}\selectfont{\sffamily\bfseries キーワード：}\sffamily\@keywords\par\vspace*{.5\baselineskip}\par\end{center}}\fi

	{\fontsize{18pt}{54pt}\sffamily\fontseries{sb}\selectfont \begin{center}
		要旨\end{center}}

	#1

}


\NewDocumentEnvironment{eabstract}{+b}{
	\cleardoublepage\phantomsection\thispagestyle{empty}

	\begin{center}
	{\fontsize{14pt}{21pt}\scshape\selectfont \@ethesistype\par}

	{\fontsize{18pt}{27pt}\sffamily\bfseries\selectfont \@etitle\par}

	\vspace*{\baselineskip}

	{\fontsize{14pt}{21pt}\selectfont \@esubtitle\par}

	\vspace*{\baselineskip}

	{Kobe University Secondary School}

	{\fontsize{14pt}{21pt}\bfseries\selectfont \@eauthor\par}

	\end{center}

	\vspace*{\baselineskip}

	\ifdefined\@ekeywords{\begin{center}\fontsize{12pt}{18pt}\selectfont{\sffamily\bfseries Keywords: }\sffamily\@ekeywords\par\vspace*{.5\baselineskip}\end{center}}\fi

	{\begin{center}	\addcontentsline{toc}{chapter}{英文要旨}
		\fontsize{18pt}{54pt}\sffamily\bfseries\selectfont Abstract\end{center}}

	#1

}

\makeatother
